******* Borenstein, AEJ-EP, "The Redistributional Impact of Non-Linear Electricity Pricing"
******* See BorensteinAEJEPReadMe.txt for description
******* PROGRAM #15 CSCALC7.DO

clear
capture log close
set more off
set mem 1200m
log using "cscalc7.slf", replace text

u c:\dropbox\billtiers\bt201102\censusdata.dta
keep bg p_*
sort bg
save c:\temp\temp4, replace

u SCEannual
drop rnd

*replace CARE=0

summ days flaguse
drop if flaguse~=1
drop flaguse
summ days

g used=use/days

**SET BASIC PROPENSITIES TO SIGN UP FOR CARE
scalar CAREshr1=0.7359
scalar CAREshr2=0.4506
scalar CAREshr3=0.1008
scalar CAREshr4=0.0063
scalar CAREshr5=0.0001

sort bg
merge bg using c:\temp\temp4
tab _merge
drop if _merge~=3
drop _merge
drop if p_under_20==.

sort bg
egen bgNCARE=sum((1-CARE)*days), by (bg)
egen bgCARE=sum(CARE*days), by (bg)
egen bgdays=sum(days), by (bg)

**SET SCALE FACTOR TO DISTRIBUTE CARE CUSTOMERS PROPORTIONALLY TO PROPENSITIES
g CAREscale=bgCARE / (bgdays * (CAREshr1*p_under_20+CAREshr2*p_20_40+CAREshr3*p_40_60+CAREshr4*p_60_100+CAREshr5*p_over_100))

g CARE1= CAREshr1*CAREscale*bgdays*p_under_20
g CARE2= CAREshr2*CAREscale*bgdays*p_20_40
g CARE3= CAREshr3*CAREscale*bgdays*p_40_60
g CARE4= CAREshr4*CAREscale*bgdays*p_60_100
g CARE5= CAREshr5*CAREscale*bgdays*p_over_100

summ CARE*

**FIX CASES IN WHICH SCALE FACTOR TAKE CARE DAYS ABOVE TOTAL DAYS IN INCOME BRACKET
**BY DISTRIBUTING DAYS TO NEXT HIGHEST INCOME BRACKET

replace CARE1=bgdays*p_under_20 if CARE1>bgdays*p_under_20
replace CARE2=bgdays*p_20_40 if CARE2>bgdays*p_20_40
replace CARE3=bgdays*p_40_60 if CARE3>bgdays*p_40_60
replace CARE4=bgdays*p_60_100 if CARE4>bgdays*p_60_100
replace CARE5=bgdays*p_over_100 if CARE5>bgdays*p_over_100

g totC=CARE1+CARE2+CARE3+CARE4+CARE5
replace CARE1=CARE1+(bgCARE-totC) if bgCARE>totC
replace CARE1=bgdays*p_under_20 if CARE1>bgdays*p_under_20

replace totC=CARE1+CARE2+CARE3+CARE4+CARE5
replace CARE2=CARE2+(bgCARE-totC) if bgCARE>totC
replace CARE2=bgdays*p_20_40 if CARE2>bgdays*p_20_40

replace totC=CARE1+CARE2+CARE3+CARE4+CARE5
replace CARE3=CARE3+(bgCARE-totC) if bgCARE>totC
replace CARE3=bgdays*p_40_60 if CARE3>bgdays*p_40_60

replace totC=CARE1+CARE2+CARE3+CARE4+CARE5
replace CARE4=CARE4+(bgCARE-totC) if bgCARE>totC
replace CARE4=bgdays*p_60_100 if CARE4>bgdays*p_60_100

replace totC=CARE1+CARE2+CARE3+CARE4+CARE5
replace CARE5=CARE5+(bgCARE-totC) if bgCARE>totC
replace CARE5=bgdays*p_over_100 if CARE5>bgdays*p_over_100

summ CARE*

replace totC=CARE1+CARE2+CARE3+CARE4+CARE5
g xx=bgCARE-totC
summ xx,d
drop xx

g NCARE1=max(0 , bgdays*p_under_20-CARE1)
g NCARE2=max(0 ,bgdays*p_20_40-CARE2)
g NCARE3=max(0 ,bgdays*p_40_60-CARE3)
g NCARE4=max(0 ,bgdays*p_60_100-CARE4)
g NCARE5=max(0 ,bgdays*p_over_100-CARE5)

g tot=CARE1+CARE2+CARE3+CARE4+CARE5+NCARE1+NCARE2+NCARE3+NCARE4+NCARE5
g totN=NCARE1+NCARE2+NCARE3+NCARE4+NCARE5
summ tot bgdays totC bgCARE totN bgNCARE if tot~=. & bgdays~=.

drop tot totC totN

sort bg used
g rankU=1 if _n==1
replace rankU=1 if bg~=bg[_n-1]
replace rankU=rankU[_n-1]+1 if rankU==.

set seed 2126423689
g rnd=uniform()
sort bg rnd
g rankR=1 if _n==1
replace rankR=1 if bg~=bg[_n-1]
replace rankR=rankR[_n-1]+1 if rankR==.

save c:\temp\temp3, replace


***  ASSIGNING INCOME BY WEIGHTED RANK METHOD

*local wgt=0

local wgt=17
while `wgt'<=43{

u c:\temp\temp3

g w=float(`wgt')/100

summ w

g rankW=(1-w)*rankR+w*rankU
sort bg rankW

g bgdaysN=.
g bgdaysC=.

replace bgdaysN=(1-CARE)*days if _n==1
replace bgdaysN=(1-CARE)*days if bg~=bg[_n-1]
replace bgdaysC=(CARE)*days if _n==1
replace bgdaysC=(CARE)*days if bg~=bg[_n-1]

replace bgdaysN=bgdaysN[_n-1]+(1-CARE)*days if bgdaysN==.
replace bgdaysC=bgdaysC[_n-1]+(CARE)*days if bgdaysC==.

g incCAREw=.
g incNCAREw=.

replace incCAREw=1 if 0.5*(bgdaysC+bgdaysC[_n-1])<CARE1 & CARE==1
replace incCAREw=2 if 0.5*(bgdaysC+bgdaysC[_n-1])>=CARE1 & 0.5*(bgdaysC+bgdaysC[_n-1])<CARE1+CARE2 & CARE==1
replace incCAREw=3 if 0.5*(bgdaysC+bgdaysC[_n-1])>=CARE1+CARE2 & 0.5*(bgdaysC+bgdaysC[_n-1])<CARE1+CARE2+CARE3 & CARE==1
replace incCAREw=4 if 0.5*(bgdaysC+bgdaysC[_n-1])>=CARE1+CARE2+CARE3 & 0.5*(bgdaysC+bgdaysC[_n-1])<CARE1+CARE2+CARE3+CARE4 & CARE==1
replace incCAREw=5 if 0.5*(bgdaysC+bgdaysC[_n-1])>=CARE1+CARE2+CARE3+CARE4 & CARE==1

replace incCAREw=1 if 0.5*(bgdaysC)<CARE1 & CARE==1 & bg~=bg[_n-1]
replace incCAREw=2 if 0.5*(bgdaysC)>=CARE1 & 0.5*(bgdaysC)<CARE1+CARE2 & CARE==1 & bg~=bg[_n-1]
replace incCAREw=3 if 0.5*(bgdaysC)>=CARE1+CARE2 & 0.5*(bgdaysC)<CARE1+CARE2+CARE3 & CARE==1 & bg~=bg[_n-1]
replace incCAREw=4 if 0.5*(bgdaysC)>=CARE1+CARE2+CARE3 & 0.5*(bgdaysC)<CARE1+CARE2+CARE3+CARE4 & CARE==1 & bg~=bg[_n-1]
replace incCAREw=5 if 0.5*(bgdaysC)>=CARE1+CARE2+CARE3+CARE4 & CARE==1 & bg~=bg[_n-1]

summ inc* CARE*

replace incNCAREw=1 if 0.5*(bgdaysN+bgdaysN[_n-1])<NCARE1 & CARE==0
replace incNCAREw=2 if 0.5*(bgdaysN+bgdaysN[_n-1])>=NCARE1 & 0.5*(bgdaysN+bgdaysN[_n-1])<NCARE1+NCARE2 & CARE==0
replace incNCAREw=3 if 0.5*(bgdaysN+bgdaysN[_n-1])>=NCARE1+NCARE2 & 0.5*(bgdaysN+bgdaysN[_n-1])<NCARE1+NCARE2+NCARE3 & CARE==0
replace incNCAREw=4 if 0.5*(bgdaysN+bgdaysN[_n-1])>=NCARE1+NCARE2+NCARE3 & 0.5*(bgdaysN+bgdaysN[_n-1])<NCARE1+NCARE2+NCARE3+NCARE4 & CARE==0
replace incNCAREw=5 if 0.5*(bgdaysN+bgdaysN[_n-1])>=NCARE1+NCARE2+NCARE3+NCARE4 & CARE==0

replace incNCAREw=1 if 0.5*(bgdaysN)<NCARE1 & CARE==0 & bg~=bg[_n-1]
replace incNCAREw=2 if 0.5*(bgdaysN)>=NCARE1 & 0.5*(bgdaysN)<NCARE1+NCARE2 & CARE==0 & bg~=bg[_n-1]
replace incNCAREw=3 if 0.5*(bgdaysN)>=NCARE1+NCARE2 & 0.5*(bgdaysN)<NCARE1+NCARE2+NCARE3 & CARE==0 & bg~=bg[_n-1]
replace incNCAREw=4 if 0.5*(bgdaysN)>=NCARE1+NCARE2+NCARE3 & 0.5*(bgdaysN)<NCARE1+NCARE2+NCARE3+NCARE4 & CARE==0 & bg~=bg[_n-1]
replace incNCAREw=5 if 0.5*(bgdaysN)>=NCARE1+NCARE2+NCARE3+NCARE4 & CARE==0 & bg~=bg[_n-1]

summ inc* NCARE*

tab incCAREw [aw=days]
tab incNCAREw [aw=days]

g incW=incCAREw if CARE==1
replace incW=incNCAREw if CARE==0

keep id aid CARE incW w
sort id aid CARE

save c:\temp\temp2, replace

merge id aid CARE using c:\billtiers\bt200908\sce\cschga1
tab _merge
drop if _merge~=3
drop _merge

drop id aid
sort incW CARE
collapse (sum) days use dmd* cs* rv* (mean) w, by(incW CARE)
sort incW CARE
save c:\temp\temp1, replace

u c:\temp\temp2
merge id aid CARE using c:\billtiers\bt200908\sce\cschga2
tab _merge
drop if _merge~=3
drop _merge

drop id aid
sort incW
collapse (sum) dmd* cs* rv*, by(incW CARE)
sort incW CARE
merge incW CARE using c:\temp\temp1
tab _merge
drop _merge

egen trv0t1=sum(rv0t1)
egen trv0t5=sum(rv0t5)
egen trv1t1=sum(rv1t1)
egen trv1t5=sum(rv1t5)

egen tdmd0q1=sum(dmd0q1)
egen tdmd0q5=sum(dmd0q5)
egen tdmd1q1=sum(dmd1q1)
egen tdmd1q5=sum(dmd1q5)

egen trv2t1=sum(rv2t1)
egen trv2t5=sum(rv2t5)
egen trv3t1=sum(rv3t1)
egen trv3t5=sum(rv3t5)

egen tdmd2q1=sum(dmd2q1)
egen tdmd2q5=sum(dmd2q5)
egen tdmd3q1=sum(dmd3q1)
egen tdmd3q5=sum(dmd3q5)

save c:\temp\temp1, replace

***************** CALCULATE CSs AT FLAT RATES ***********

********************  MC=0.0592 ************************

******  MC=0.0592, elas=0 CARECASE=0

u c:\temp\temp1
g MC=0.0592
g FC=trv0t5-MC*tdmd0q5
g elas=-0.0
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs0t1
g csbase=cs0t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv0t1/tdmd0q1
g Q=tdmd0q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd0q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA


*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.0592, elas=0 CARECASE=1

u c:\temp\temp1
g MC=0.0592
g FC=trv0t5-MC*tdmd0q5
g elas=-0.0
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs0t1
g csbase=cs0t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv0t1/tdmd0q1
g Q=tdmd0q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd0q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear


******  MC=0.0592, elas=-0.1 CARECASE=0

u c:\temp\temp1
g MC=0.0592
g FC=trv1t5-MC*tdmd1q5
g elas=-0.1
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs1t1
g csbase=cs1t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv1t1/tdmd1q1
g Q=tdmd1q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd1q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.0592, elas=-0.1 CARECASE=1

u c:\temp\temp1
g MC=0.0592
g FC=trv1t5-MC*tdmd1q5
g elas=-0.1
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs1t1
g csbase=cs1t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv1t1/tdmd1q1
g Q=tdmd1q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd1q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear



******  MC=0.0592, elas=-0.2 CARECASE=0

u c:\temp\temp1
g MC=0.0592
g FC=trv2t5-MC*tdmd2q5
g elas=-0.2
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs2t1
g csbase=cs2t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv2t1/tdmd2q1
g Q=tdmd2q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd2q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.0592, elas=-0.2 CARECASE=1

u c:\temp\temp1
g MC=0.0592
g FC=trv2t5-MC*tdmd2q5
g elas=-0.2
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs2t1
g csbase=cs2t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv2t1/tdmd2q1
g Q=tdmd2q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd2q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear




******  MC=0.0592, elas=-0.3 CARECASE=0

u c:\temp\temp1
g MC=0.0592
g FC=trv3t5-MC*tdmd3q5
g elas=-0.3
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs3t1
g csbase=cs3t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv3t1/tdmd3q1
g Q=tdmd3q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd3q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.0592, elas=-0.3 CARECASE=1

u c:\temp\temp1
g MC=0.0592
g FC=trv3t5-MC*tdmd3q5
g elas=-0.3
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs3t1
g csbase=cs3t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv3t1/tdmd3q1
g Q=tdmd3q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd3q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear



********************  MC=0.1092 ************************

******  MC=0.1092, elas=0 CARECASE=0

u c:\temp\temp1
g MC=0.1092
g FC=trv0t5-MC*tdmd0q5
g elas=-0.0
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs0t1
g csbase=cs0t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv0t1/tdmd0q1
g Q=tdmd0q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd0q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA


*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.1092, elas=0 CARECASE=1

u c:\temp\temp1
g MC=0.1092
g FC=trv0t5-MC*tdmd0q5
g elas=-0.0
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs0t1
g csbase=cs0t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv0t1/tdmd0q1
g Q=tdmd0q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd0q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear


******  MC=0.1092, elas=-0.1 CARECASE=0

u c:\temp\temp1
g MC=0.1092
g FC=trv1t5-MC*tdmd1q5
g elas=-0.1
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs1t1
g csbase=cs1t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv1t1/tdmd1q1
g Q=tdmd1q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd1q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.1092, elas=-0.1 CARECASE=1

u c:\temp\temp1
g MC=0.1092
g FC=trv1t5-MC*tdmd1q5
g elas=-0.1
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs1t1
g csbase=cs1t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv1t1/tdmd1q1
g Q=tdmd1q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd1q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear



******  MC=0.1092, elas=-0.2 CARECASE=0

u c:\temp\temp1
g MC=0.1092
g FC=trv2t5-MC*tdmd2q5
g elas=-0.2
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs2t1
g csbase=cs2t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv2t1/tdmd2q1
g Q=tdmd2q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd2q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.1092, elas=-0.2 CARECASE=1

u c:\temp\temp1
g MC=0.1092
g FC=trv2t5-MC*tdmd2q5
g elas=-0.2
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs2t1
g csbase=cs2t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv2t1/tdmd2q1
g Q=tdmd2q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd2q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear




******  MC=0.1092, elas=-0.3 CARECASE=0

u c:\temp\temp1
g MC=0.1092
g FC=trv3t5-MC*tdmd3q5
g elas=-0.3
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs3t1
g csbase=cs3t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv3t1/tdmd3q1
g Q=tdmd3q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd3q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.1092, elas=-0.3 CARECASE=1

u c:\temp\temp1
g MC=0.1092
g FC=trv3t5-MC*tdmd3q5
g elas=-0.3
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs3t1
g csbase=cs3t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv3t1/tdmd3q1
g Q=tdmd3q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd3q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear




********************  MC=0.1592 ************************

******  MC=0.1592, elas=0 CARECASE=0

u c:\temp\temp1
g MC=0.1592
g FC=trv0t5-MC*tdmd0q5
g elas=-0.0
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs0t1
g csbase=cs0t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv0t1/tdmd0q1
g Q=tdmd0q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd0q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA


*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.1592, elas=0 CARECASE=1

u c:\temp\temp1
g MC=0.1592
g FC=trv0t5-MC*tdmd0q5
g elas=-0.0
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs0t1
g csbase=cs0t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv0t1/tdmd0q1
g Q=tdmd0q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd0q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear


******  MC=0.1592, elas=-0.1 CARECASE=0

u c:\temp\temp1
g MC=0.1592
g FC=trv1t5-MC*tdmd1q5
g elas=-0.1
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs1t1
g csbase=cs1t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv1t1/tdmd1q1
g Q=tdmd1q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd1q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.1592, elas=-0.1 CARECASE=1

u c:\temp\temp1
g MC=0.1592
g FC=trv1t5-MC*tdmd1q5
g elas=-0.1
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs1t1
g csbase=cs1t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv1t1/tdmd1q1
g Q=tdmd1q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd1q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear



******  MC=0.1592, elas=-0.2 CARECASE=0

u c:\temp\temp1
g MC=0.1592
g FC=trv2t5-MC*tdmd2q5
g elas=-0.2
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs2t1
g csbase=cs2t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv2t1/tdmd2q1
g Q=tdmd2q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd2q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.1592, elas=-0.2 CARECASE=1

u c:\temp\temp1
g MC=0.1592
g FC=trv2t5-MC*tdmd2q5
g elas=-0.2
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs2t1
g csbase=cs2t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv2t1/tdmd2q1
g Q=tdmd2q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd2q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear




******  MC=0.1592, elas=-0.3 CARECASE=0

u c:\temp\temp1
g MC=0.1592
g FC=trv3t5-MC*tdmd3q5
g elas=-0.3
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs3t1
g csbase=cs3t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv3t1/tdmd3q1
g Q=tdmd3q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd3q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.1592, elas=-0.3 CARECASE=1

u c:\temp\temp1
g MC=0.1592
g FC=trv3t5-MC*tdmd3q5
g elas=-0.3
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs3t1
g csbase=cs3t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv3t1/tdmd3q1
g Q=tdmd3q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd3q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear





********************  MC=0.2092 ************************

******  MC=0.2092, elas=0 CARECASE=0

u c:\temp\temp1
g MC=0.2092
g FC=trv0t5-MC*tdmd0q5
g elas=-0.0
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs0t1
g csbase=cs0t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv0t1/tdmd0q1
g Q=tdmd0q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd0q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA


*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.2092, elas=0 CARECASE=1

u c:\temp\temp1
g MC=0.2092
g FC=trv0t5-MC*tdmd0q5
g elas=-0.0
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs0t1
g csbase=cs0t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv0t1/tdmd0q1
g Q=tdmd0q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd0q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear


******  MC=0.2092, elas=-0.1 CARECASE=0

u c:\temp\temp1
g MC=0.2092
g FC=trv1t5-MC*tdmd1q5
g elas=-0.1
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs1t1
g csbase=cs1t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv1t1/tdmd1q1
g Q=tdmd1q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd1q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.2092, elas=-0.1 CARECASE=1

u c:\temp\temp1
g MC=0.2092
g FC=trv1t5-MC*tdmd1q5
g elas=-0.1
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs1t1
g csbase=cs1t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv1t1/tdmd1q1
g Q=tdmd1q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd1q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear



******  MC=0.2092, elas=-0.2 CARECASE=0

u c:\temp\temp1
g MC=0.2092
g FC=trv2t5-MC*tdmd2q5
g elas=-0.2
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs2t1
g csbase=cs2t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv2t1/tdmd2q1
g Q=tdmd2q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd2q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.2092, elas=-0.2 CARECASE=1

u c:\temp\temp1
g MC=0.2092
g FC=trv2t5-MC*tdmd2q5
g elas=-0.2
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs2t1
g csbase=cs2t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv2t1/tdmd2q1
g Q=tdmd2q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd2q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear




******  MC=0.2092, elas=-0.3 CARECASE=0

u c:\temp\temp1
g MC=0.2092
g FC=trv3t5-MC*tdmd3q5
g elas=-0.3
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs3t1
g csbase=cs3t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv3t1/tdmd3q1
g Q=tdmd3q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd3q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.2092, elas=-0.3 CARECASE=1

u c:\temp\temp1
g MC=0.2092
g FC=trv3t5-MC*tdmd3q5
g elas=-0.3
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs3t1
g csbase=cs3t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv3t1/tdmd3q1
g Q=tdmd3q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd3q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear





********************  MC=0.2592 ************************

******  MC=0.2592, elas=0 CARECASE=0

u c:\temp\temp1
g MC=0.2592
g FC=trv0t5-MC*tdmd0q5
g elas=-0.0
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs0t1
g csbase=cs0t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv0t1/tdmd0q1
g Q=tdmd0q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd0q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA


*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.2592, elas=0 CARECASE=1

u c:\temp\temp1
g MC=0.2592
g FC=trv0t5-MC*tdmd0q5
g elas=-0.0
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs0t1
g csbase=cs0t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv0t1/tdmd0q1
g Q=tdmd0q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd0q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear


******  MC=0.2592, elas=-0.1 CARECASE=0

u c:\temp\temp1
g MC=0.2592
g FC=trv1t5-MC*tdmd1q5
g elas=-0.1
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs1t1
g csbase=cs1t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv1t1/tdmd1q1
g Q=tdmd1q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd1q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.2592, elas=-0.1 CARECASE=1

u c:\temp\temp1
g MC=0.2592
g FC=trv1t5-MC*tdmd1q5
g elas=-0.1
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs1t1
g csbase=cs1t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv1t1/tdmd1q1
g Q=tdmd1q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd1q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear



******  MC=0.2592, elas=-0.2 CARECASE=0

u c:\temp\temp1
g MC=0.2592
g FC=trv2t5-MC*tdmd2q5
g elas=-0.2
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs2t1
g csbase=cs2t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv2t1/tdmd2q1
g Q=tdmd2q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd2q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.2592, elas=-0.2 CARECASE=1

u c:\temp\temp1
g MC=0.2592
g FC=trv2t5-MC*tdmd2q5
g elas=-0.2
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs2t1
g csbase=cs2t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv2t1/tdmd2q1
g Q=tdmd2q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd2q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear




******  MC=0.2592, elas=-0.3 CARECASE=0

u c:\temp\temp1
g MC=0.2592
g FC=trv3t5-MC*tdmd3q5
g elas=-0.3
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=0
g cs=cs3t1
g csbase=cs3t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv3t1/tdmd3q1
g Q=tdmd3q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd3q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)

*DETERMINE NET VARIABLE PROFIT AT FLAT-PRICE DEMAND GIVEN ELASTICITY
*DIVIDE BY REVENUE TO GET PRICE ADJUSTMENT (IF THERE WERE NO ELASTICITY)
g Padj=(Q*P-MC*Q-FC)/(Q*P)
*DETERMINE ADJUSTED PRICE AND QUANTITIES
g PA=(1-Padj)*P
g QA=tA*PA^elas
summ PA QA P 

*DO PRICE ADJUSTMENT REPEATEDLY TO GET VERY CLOSE TO BREAK EVEN PRICE
replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

replace Padj=((PA-MC)*QA-FC)/(QA*PA)
replace PA=(1-Padj)*PA
replace QA=tA*PA^elas
summ PA QA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))
g qA=A*PA^elas

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

******  MC=0.2592, elas=-0.3 CARECASE=1

u c:\temp\temp1
g MC=0.2592
g FC=trv3t5-MC*tdmd3q5
g elas=-0.3
*CAREcase= 0 (NO CARE PROGRAM), OR 1 (CARE PROGRAM)
g CAREcase=1
g CAREdisc=0.612363
g cs=cs3t1
g csbase=cs3t5

*DETERMINE PRICE AT WHICH FLAT-PRICE DEMAND WAS CALCULATED
g P=trv3t1/tdmd3q1
g Q=tdmd3q1
*DETERMINE "A" TERM IN DEMAND FUNCTION FOR THIS GROUP
g A=dmd3q1/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR ALL DEMAND
g tA=Q/(P^elas)
*DETERMINE AGGREGATE "A" TERM FOR CARE AND NON-CARE DEMAND CATEGORIES
sort CARE
g PA=(0.1731/0.1592)*P
replace PA=PA*CAREdisc if CARE==1

g q=A*PA^elas
g VP=(PA-MC)*q
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
g qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

drop tVP TR VP Padj
g VP=(PA-MC)*qA
egen tVP=sum(VP)
egen TR=sum(q*PA)
g Padj=(tVP-FC)/TR
replace PA=(1-Padj)*PA
replace qA=A*PA^elas
summ PA qA

*CALCULATE CS AT THIS PRICE
g csA=cs+(A/(elas+1))*(P^(elas+1)-PA^(elas+1))

keep w MC elas CARE incW PA qA csA csbase days CAREcase
sort w MC elas CARE incW
summ w MC elas CAREcase csbase
list CARE incW PA qA csA days
capture append using cscalc7
save cscalc7, replace
clear

local wgt=`wgt'+1

}


exit